@@ -12,15 +12,15 @@ def breaking_ties(probabilities):
     # The extra minus is redundant but I kept as a highlight of the change in the
     # original formula.
     bt = -(probs_sorted[:, 0] - probs_sorted[:, 1])
-    return (bt - bt.min(0)) / (bt.max(0) - bt.min(0))
+    return bt
 
 
 UNCERTAINTY_FUNCTIONS = {
-    'entropy': (
+    "entropy": (
         lambda probabilities: (-probabilities * np.log2(probabilities)).sum(axis=1)
     ),
-    'breaking_ties': breaking_ties,
-    'random': (
+    "breaking_ties": breaking_ties,
+    "random": (
         lambda probabilities: np.ones(probabilities.shape[0]) / probabilities.shape[0]
-    )
+    ),
 }
