@@ -13,13 +13,13 @@ from ._metrics import (
     geometric_mean_score_macro,
     ALScorer,
     area_under_learning_curve,
-    data_utilization_rate
+    data_utilization_rate,
 )
 
 __all__ = [
-    'SCORERS',
-    'geometric_mean_score_macro',
-    'area_under_learning_curve',
-    'data_utilization_rate',
-    'ALScorer'
+    "SCORERS",
+    "geometric_mean_score_macro",
+    "area_under_learning_curve",
+    "data_utilization_rate",
+    "ALScorer",
 ]
